@@ -47,8 +47,9 @@ Forest::Forest() :
     verbose_out(0), num_trees(DEFAULT_NUM_TREE), mtry(0), min_node_size(0), num_variables(0), num_independent_variables(
         0), seed(0), dependent_varID(0), num_samples(0), prediction_mode(false), memory_mode(MEM_DOUBLE), sample_with_replacement(
         true), memory_saving_splitting(false), splitrule(DEFAULT_SPLITRULE), predict_all(false), keep_inbag(false), sample_fraction(
-        1), holdout(false), alpha(DEFAULT_ALPHA), minprop(DEFAULT_MINPROP), num_threads(DEFAULT_NUM_THREADS), data(0), overall_prediction_error(
-        0), importance_mode(DEFAULT_IMPORTANCE_MODE), progress(0) {
+        1), holdout(false), prediction_type(DEFAULT_PREDICTIONTYPE), alpha(DEFAULT_ALPHA), minprop(DEFAULT_MINPROP), num_threads(
+        DEFAULT_NUM_THREADS), data(0), overall_prediction_error(0), importance_mode(DEFAULT_IMPORTANCE_MODE), progress(
+        0) {
 }
 
 Forest::~Forest() {
@@ -63,7 +64,7 @@ void Forest::initCpp(std::string dependent_variable_name, MemoryMode memory_mode
     std::string split_select_weights_file, std::vector<std::string>& always_split_variable_names,
     std::string status_variable_name, bool sample_with_replacement, std::vector<std::string>& unordered_variable_names,
     bool memory_saving_splitting, SplitRule splitrule, std::string case_weights_file, bool predict_all,
-    double sample_fraction, double alpha, double minprop, bool holdout) {
+    double sample_fraction, double alpha, double minprop, bool holdout, PredictionType prediction_type) {
 
   this->verbose_out = verbose_out;
 
@@ -97,7 +98,7 @@ void Forest::initCpp(std::string dependent_variable_name, MemoryMode memory_mode
   // Call other init function
   init(dependent_variable_name, memory_mode, data, mtry, output_prefix, num_trees, seed, num_threads, importance_mode,
       min_node_size, status_variable_name, prediction_mode, sample_with_replacement, unordered_variable_names,
-      memory_saving_splitting, splitrule, predict_all, sample_fraction, alpha, minprop, holdout);
+      memory_saving_splitting, splitrule, predict_all, sample_fraction, alpha, minprop, holdout, prediction_type);
 
   if (prediction_mode) {
     loadFromFile(load_forest_filename);
@@ -153,14 +154,14 @@ void Forest::initR(std::string dependent_variable_name, Data* input_data, uint m
     std::string status_variable_name, bool prediction_mode, bool sample_with_replacement,
     std::vector<std::string>& unordered_variable_names, bool memory_saving_splitting, SplitRule splitrule,
     std::vector<double>& case_weights, bool predict_all, bool keep_inbag, double sample_fraction, double alpha,
-    double minprop, bool holdout) {
+    double minprop, bool holdout, PredictionType prediction_type) {
 
   this->verbose_out = verbose_out;
 
   // Call other init function
   init(dependent_variable_name, MEM_DOUBLE, input_data, mtry, "", num_trees, seed, num_threads, importance_mode,
       min_node_size, status_variable_name, prediction_mode, sample_with_replacement, unordered_variable_names,
-      memory_saving_splitting, splitrule, predict_all, sample_fraction, alpha, minprop, holdout);
+      memory_saving_splitting, splitrule, predict_all, sample_fraction, alpha, minprop, holdout, prediction_type);
 
   // Set variables to be always considered for splitting
   if (!always_split_variable_names.empty()) {
@@ -188,7 +189,8 @@ void Forest::init(std::string dependent_variable_name, MemoryMode memory_mode, D
     std::string output_prefix, uint num_trees, uint seed, uint num_threads, ImportanceMode importance_mode,
     uint min_node_size, std::string status_variable_name, bool prediction_mode, bool sample_with_replacement,
     std::vector<std::string>& unordered_variable_names, bool memory_saving_splitting, SplitRule splitrule,
-    bool predict_all, double sample_fraction, double alpha, double minprop, bool holdout) {
+    bool predict_all, double sample_fraction, double alpha, double minprop, bool holdout,
+    PredictionType prediction_type) {
 
   // Initialize data with memmode
   this->data = input_data;
@@ -229,6 +231,7 @@ void Forest::init(std::string dependent_variable_name, MemoryMode memory_mode, D
   this->holdout = holdout;
   this->alpha = alpha;
   this->minprop = minprop;
+  this->prediction_type = prediction_type;
 
   // Set number of samples and variables
   num_samples = data->getNumRows();
