@@ -51,7 +51,7 @@ Rcpp::List rangerCpp(uint treetype, std::string dependent_variable_name,
     bool sample_with_replacement, bool probability, std::vector<std::string>& unordered_variable_names,
     bool use_unordered_variable_names, bool save_memory, uint splitrule_r, 
     std::vector<double>& case_weights, bool use_case_weights, bool predict_all, 
-    bool keep_inbag, double sample_fraction, double alpha, double minprop, bool holdout) {
+    bool keep_inbag, double sample_fraction, double alpha, double minprop, bool holdout, uint prediction_type_r) {
 
   Rcpp::List result;
   Forest* forest = 0;
@@ -111,12 +111,13 @@ Rcpp::List rangerCpp(uint treetype, std::string dependent_variable_name,
 
     ImportanceMode importance_mode = (ImportanceMode) importance_mode_r;
     SplitRule splitrule = (SplitRule) splitrule_r;
+    PredictionType prediction_type = (PredictionType) prediction_type_r;
 
     // Init Ranger
     forest->initR(dependent_variable_name, data, mtry, num_trees, verbose_out, seed, num_threads,
         importance_mode, min_node_size, split_select_weights, always_split_variable_names, status_variable_name,
         prediction_mode, sample_with_replacement, unordered_variable_names, save_memory, splitrule, case_weights, 
-        predict_all, keep_inbag, sample_fraction, alpha, minprop, holdout);
+        predict_all, keep_inbag, sample_fraction, alpha, minprop, holdout, prediction_type);
 
     // Load forest object if in prediction mode
     if (prediction_mode) {
@@ -174,7 +175,9 @@ Rcpp::List rangerCpp(uint treetype, std::string dependent_variable_name,
     if (!prediction_mode) {
       result.push_back(forest->getMtry(), "mtry");
       result.push_back(forest->getMinNodeSize(), "min.node.size");
-      result.push_back(forest->getVariableImportance(), "variable.importance");
+      if (importance_mode != IMP_NONE) {
+        result.push_back(forest->getVariableImportance(), "variable.importance");
+      }
       result.push_back(forest->getOverallPredictionError(), "prediction.error");
     }
     
